@@ -2,7 +2,7 @@ import pygame
 
 
 class Button:
-    def __init__(self,window,pos,size,colour,txt_obj, listeners, listener_atributes):
+    def __init__(self,window,pos,size,colour,txt_obj, listeners = [], listener_atributes = []):
         self.window = window
         self.pos = pos
         self.size = size
